<?php
// https://understanddrupal.com/articles/how-debug-drupal-migrations-part-2

namespace Drupal\popsu_migrate\Plugin\migrate\source;

use Drupal\migrate\Row;
use Drush\Drush;

// use Drupal\popsu_migrate\Plugin\migrate\source\D7Programme;

/**
 * Drupal 7 node source from database.
 *
 * @MigrateSource(
 *   id = "d7_node_programme",
 *   source_module = "node"
 * )
 */
class D7NodeProgramme extends D7Programme {

  /**
   * {@inheritdoc}
   */
  public function prepareRow(Row $row) {
    $nid = $row->getSourceProperty('nid');
    $vid = $row->getSourceProperty('vid');
    $type = $row->getSourceProperty('type');

    // Get Field API field values.
    foreach ($this->getFields('node', $type) as $field_name => $field) {
      // Ensure we're using the right language if the entity and the field are
      // translatable.
      // $field_language = $entity_translatable && $field['translatable'] ? $language : NULL;
      $row->setSourceProperty($field_name, $this->getFieldValues('node', $field_name, $nid, $vid, NULL));
    }

    // title from taxo term
    $field_popsu_special_popsu_tid = $row->getSourceProperty('field_popsu_special_popsu')[0]['tid'];
    $q = $this->select('taxonomy_term_data', 'ttd')
      ->fields('ttd', ['tid','name'])
      ->condition('tid', $field_popsu_special_popsu_tid);
    $term = $q->execute()->fetchAll();
    // Drush::output()->writeln(dump($term));
    $row->setSourceProperty('term_title', $term[0]['name']);

    // text intro
    $body = $row->getSourceProperty('field_popsu_special_body');
    $row->setSourceProperty('body', $body[0]['value']);
    $row->setSourceProperty('body_summary', $body[0]['summary']);

    // texts (migration_lookup)
    $row->setSourceProperty('text_paragraphe_id', $nid);

    // associateds
    $associateds = $this->getAssociatedSpecial($field_popsu_special_popsu_tid);
    Drush::output()->writeln(dump($associateds));

    // fichiers
    $fichiers = array();
    foreach ($row->getSourceProperty('field_popsu_special_insert') as $value) {
      $fichiers[] = $value;
    }
    foreach ($row->getSourceProperty('field_popsu_special_insert_intro') as $value) {
      $fichiers[] = $value;
    }
    // files from associated nodes (colloques, publications, partenaires)
    foreach ( ['colloques', 'publications'] as $name) {
      foreach ($associateds[$name] as $key => $asso) {
        // tried with array merge but it failed
        // and apparently foreach is faster than array_merge
        foreach ($asso['field_popsu_special_insert'] as $value) {
          $fichiers[] = $value;
        }
        foreach ($asso['field_popsu_special_insert_intro'] as $value) {
          $fichiers[] = $value;
        }
      }
    }
    $row->setSourceProperty('fichiers', $fichiers);

    return parent::prepareRow($row);
  }

}
